==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/distributedTest/java/org/apache/geode/internal/cache/ARMLockTestHookAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import java.io.Serializable;

import org.apache.geode.cache.CacheEvent;

public class ARMLockTestHookAdapter implements AbstractRegionMap.ARMLockTestHook, Serializable {

  @Override
  public void beforeBulkLock(InternalRegion region) {};

  @Override
  public void afterBulkLock(InternalRegion region) {};

  @Override
  public void beforeBulkRelease(InternalRegion region) {};

  @Override
  public void afterBulkRelease(InternalRegion region) {};

  @Override
  public void beforeLock(InternalRegion region, CacheEvent event) {};

  @Override
  public void afterLock(InternalRegion region, CacheEvent event) {};

  @Override
  public void beforeRelease(InternalRegion region, CacheEvent event) {};

  @Override
  public void afterRelease(InternalRegion region, CacheEvent event) {};

  @Override
  public void beforeStateFlushWait() {}
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/distributedTest/java/org/apache/geode/internal/cache/ARMLockTestHookAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import java.io.Serializable;

import org.apache.geode.cache.CacheEvent;

public class ARMLockTestHookAdapter implements AbstractRegionMap.ARMLockTestHook, Serializable {

  @Override
  public void beforeBulkLock(InternalRegion region) {}

  @Override
  public void afterBulkLock(InternalRegion region) {}

  @Override
  public void beforeBulkRelease(InternalRegion region) {}

  @Override
  public void afterBulkRelease(InternalRegion region) {}

  @Override
  public void beforeLock(InternalRegion region, CacheEvent event) {}

  @Override
  public void afterLock(InternalRegion region, CacheEvent event) {}

  @Override
  public void beforeRelease(InternalRegion region, CacheEvent event) {}

  @Override
  public void afterRelease(InternalRegion region, CacheEvent event) {}

  @Override
  public void beforeStateFlushWait() {}
}
